==> cuyo_1.8.5.orig.tar.gz: cuyo-1.8.5/src/global.cpp <==
/***************************************************************************
                          global.cpp  -  description
                             -------------------
    begin                : Mit Jul 12 22:54:51 MEST 2000
    copyright            : (C) 2000 by Immi
    email                : cuyo@pcpool.mathematik.uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "global.h"


#ifdef WIN32
/* Appearently, in the Windows Version of QT, this is missig???
   If you're trying to compile cuyo for windows and this isn't missing,
   simply remove the following lines... */
QApplication* qApp;
QString QString::null="";
QStringData* QString::shared_null=0;
QColor mywhite(255,255,255);
QColor myblack(0,0,0);
QColor mygray(192,192,192);

QColor &Qt::white=mywhite;
QColor &Qt::black=myblack;
QColor &Qt::lightGray=mygray;
#endif




/** True, wenn -d bergeben wurde, d. h. im Debug-Modus. */
bool gDebug;


/** Pfad, wo das Cuyo-Programm liegt, das aufgerufen wurde (aus
    argv[0] extrahiert. Wird vom PfadIterator gebraucht, um nach
    Leveln zu suchen. */
__String gCuyoPfad;


/** True, wenn der Benutzer den Namen einer ld-Datei bergeben hat. */
bool gDateiUebergeben;


/** Wenn ein Level-Datei-Name als Parameter bergeben wurde... */
__String gLevelDatei;






/** Entfernt von p alles, was nach dem ersten Punkt kommt. Ist dazu da
    um aus einem "bla.xpm", was unter pics steht, den Namen fr Programme
    zu extrahieren. */
__String picsEndungWeg(const __String & p) {
  for (int i = 0; i < (int) p.length(); i++) {
    /* Etwas brutal: Alles ab dem ersten Punkt weg. */
    if (p[i] == '.')
      return p.left(i);
  }
  /* Keine Endung... */
  return p;
}






/** d sollte ein Pfad mit Dateiname sein. Liefert nur den Pfad-Anteil
    zurck (d. h. alles vor dem letzten "/". Liefer "./", falls d keinen
    "/" enthlt. */
__String nimmPfad(__String d) {
  /* Letzten Slash suchen */
  for (int i = d.length(); i--; ) {
    if (d[i] == '/') {
      /* Letzten Slash gefunden. Das Links davon ist der Pfad */
      return d.left(i + 1);
    }
  }
  /* Kein "/" gefunden, also offenbar im aktuellen Verzeichnis. */
  return "./";
}

==> cuyo_2.1.0.orig.tar.gz: cuyo-2.1.0/src/global.cpp <==
/***************************************************************************
                          global.cpp  -  description
                             -------------------
    begin                : Mit Jul 12 22:54:51 MEST 2000
    copyright            : (C) 2000 by Immi
    email                : cuyo@pcpool.mathematik.uni-freiburg.de

Modified 2002,2006,2008,2010,2011 by the cuyo developers

 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "global.h"
#include "stringzeug.h"





/** True, wenn -d bergeben wurde, d. h. im Debug-Modus. */
bool gDebug;


/** Pfad, wo das Cuyo-Programm liegt, das aufgerufen wurde (aus
    argv[0] extrahiert. Wird vom PfadIterator gebraucht, um nach
    Leveln zu suchen. */
Str gCuyoPfad;


/** True, wenn der Benutzer den Namen einer ld-Datei bergeben hat. */
bool gDateiUebergeben;


/** Wenn ein Level-Datei-Name als Parameter bergeben wurde... */
Str gLevelDatei;







/** Entfernt von p alles, was nach dem ersten Punkt kommt. Ist dazu da
    um aus einem "bla.xpm", was unter pics steht, den Namen fr Programme
    zu extrahieren. */
Str picsEndungWeg(const Str & p) {
  for (int i = 0; i < (int) p.length(); i++) {
    /* Etwas brutal: Alles ab dem ersten Punkt weg. */
    if (p[i] == '.')
      return p.left(i);
  }
  /* Keine Endung... */
  return p;
}



/** d sollte ein Pfad mit Dateiname sein. Liefert nur den Pfad-Anteil
    zurck (d. h. alles vor dem letzten "/". Liefer "./", falls d keinen
    "/" enthlt. */
Str nimmPfad(Str d) {
  /* Letzten Slash suchen */
  for (int i = d.length(); i--; ) {
    if (d[i] == '/') {
      /* Letzten Slash gefunden. Das Links davon ist der Pfad */
      return d.left(i + 1);
    }
  }
  /* Kein "/" gefunden, also offenbar im aktuellen Verzeichnis. */
  return "./";
}


Str vergissPfad(Str d) {
  /* Letzten Slash suchen */
  for (int i = d.length(); i--; ) {
    if (d[i] == '/') {
      /* Letzten Slash gefunden. Das rechts davon ist, was wir wollen. */
      return d.right(i + 1);
    }
  }
  /* Kein "/" gefunden, also machen wir eine Kopie. */
  Str kopie = d;
  return kopie;
}
